/**
 * 会员管理
 */

import { INDIVIDUALMEMBERTYPE, MEMBERLEVEL, MEMBERSTATE, MEMBERTYPE, UNITMEMBERTYPE } from "../../config/enum";
import { ERRORENUM } from "../../config/errorEnum";
import { TABLEENUM } from "../../data/models/model";
import { findCount, findOnce, findToPage } from "../../data/select";
import { updateOneData } from "../../data/update";
import { successResult } from "../../tools/system";
import { BizError } from "../../util/bizError";
import { extractData } from "../../util/piecemeal";
import { changeEnumValue } from "../../util/verificationEnum";



/**
 * 会员权限列表
 * @param unitName 单位名称
 * @param memberLevel 会员等级、职务 MEMBERLEVEL
 * @param memberCategory 会员类别、会员级别  UNITMEMBERTYPE、INDIVIDUALMEMBERTYPE
 * @param pageNumber 当前页
 */
 export async function getAuthority({unitName, memberLevel, memberCategory, pageNumber}) {
    let selectParam:any = {};

    if (unitName) selectParam.unitName = unitName;
    if (memberLevel) selectParam.memberLevel = memberLevel;
    if (memberCategory || memberCategory>=9) selectParam.unitMemberType = memberCategory;
    if (memberCategory || memberCategory<9) selectParam.individualMemberType = memberCategory;

    let selectConf = ["userId", "memberState", "unitName", "memberLevel"];
    let dbList = await findToPage(TABLEENUM.用户表, selectParam, [], pageNumber, 10);
    let dataCount = await findCount(TABLEENUM.用户表, selectParam);

    let dataList = [];
    dbList.forEach(info => {
        if (info.memberType == MEMBERTYPE.个人会员) {
            selectConf.push("individualMemberType");
        } else {
            selectConf.push("unitMemberType");
        }
        let item:any = extractData(info, selectConf);

        item.memberState = changeEnumValue(MEMBERSTATE, item.memberState);
        item.memberLevel = changeEnumValue(MEMBERLEVEL, item.memberLevel);
        if(item.individualMemberType) item.individualMemberType = changeEnumValue(INDIVIDUALMEMBERTYPE, item.individualMemberType);
        if(item.unitMemberType) item.unitMemberType = changeEnumValue(UNITMEMBERTYPE, item.unitMemberType);
        
        dataList.push(item);
    });

    return {dataList, dataCount};
}


/**
 * 变更权限
 * @param param0 
 */
export async function updateAuthority({form, userId}) {
    let oldInfo = await findOnce(TABLEENUM.用户表, {userId});
    if (!oldInfo || !oldInfo.userId) throw new BizError(ERRORENUM.目标数据不存在);
    await updateOneData(TABLEENUM.用户表, {userId}, form);

    return successResult();

}


/**
 * 冻结
 * @param param0 
 */
export async function freeze({userId}) {
    let oldInfo = await findOnce(TABLEENUM.用户表, {userId});
    if (!oldInfo || !oldInfo.userId) throw new BizError(ERRORENUM.目标数据不存在);
    await updateOneData(TABLEENUM.用户表, {userId}, {memberState:MEMBERSTATE.冻结});

    return successResult();

}










